@@ -1,5 +1,7 @@
 #!/bin/bash
 
+declare -r BASHUNIT_GIT_REPO="https://github.com/TypedDevs/bashunit"
+
 #
 # @param $1 string Eg: "test_some_logic_camelCase"
 #
@@ -83,22 +85,14 @@ function helper::get_functions_to_run() {
 # @param $1 string Eg: "do_something"
 #
 function helper::execute_function_if_exists() {
-  local function_name=$1
-
-  if declare -F | awk '{print $3}' | grep -Eq "^${function_name}$"; then
-    "$function_name"
-  fi
+  "$1" 2>/dev/null
 }
 
 #
 # @param $1 string Eg: "do_something"
 #
 function helper::unset_if_exists() {
-  local function_name=$1
-
-  if declare -F | awk '{print $3}' | grep -Eq "^${function_name}$"; then
-    unset "$function_name"
-  fi
+  unset "$1" 2>/dev/null
 }
 
 function helper::find_files_recursive() {
@@ -147,11 +141,19 @@ function helper::get_provider_data() {
 }
 
 function helper::trim() {
-    local input_string="$1"
-    local trimmed_string
+  local input_string="$1"
+  local trimmed_string
 
-    trimmed_string="${input_string#"${input_string%%[![:space:]]*}"}"
-    trimmed_string="${trimmed_string%"${trimmed_string##*[![:space:]]}"}"
+  trimmed_string="${input_string#"${input_string%%[![:space:]]*}"}"
+  trimmed_string="${trimmed_string%"${trimmed_string##*[![:space:]]}"}"
 
-    echo "$trimmed_string"
+  echo "$trimmed_string"
+}
+
+function helpers::get_latest_tag() {
+  git ls-remote --tags "$BASHUNIT_GIT_REPO" |
+    awk '{print $2}' |
+    sed 's|^refs/tags/||' |
+    sort -Vr |
+    head -n 1
 }
