@@ -34,16 +34,33 @@ function runner::load_test_files() {
   done
 }
 
+function runner::functions_for_script() {
+  local script="$1"
+  local all_function_names="$2"
+
+  # Filter the names down to the ones defined in the script, sort them by line
+  # number
+  shopt -s extdebug
+  for f in $all_function_names; do
+    declare -F "$f" | grep "$script"
+  done | sort -k2 -n | awk '{print $1}'
+  shopt -u extdebug
+}
+
 function runner::call_test_functions() {
   local script="$1"
   local filter="$2"
   local prefix="test"
   # Use declare -F to list all function names
-  local function_names
-  function_names=$(declare -F | awk '{print $3}')
+  local all_function_names
+  all_function_names=$(declare -F | awk '{print $3}')
+  local filtered_functions
+  # shellcheck disable=SC2207
+  filtered_functions=$(helper::get_functions_to_run "$prefix" "$filter" "$all_function_names")
+
   local functions_to_run
   # shellcheck disable=SC2207
-  functions_to_run=($(helper::get_functions_to_run "$prefix" "$filter" "$function_names"))
+  functions_to_run=($(runner::functions_for_script "$script" "$filtered_functions"))
 
   if [[ "${#functions_to_run[@]}" -gt 0 ]]; then
     if [[ "$SIMPLE_OUTPUT" == false ]]; then
@@ -190,32 +207,24 @@ function runner::run_test() {
 }
 
 function runner::run_set_up() {
-  helper::execute_function_if_exists 'setUp' # Deprecated: please use set_up instead.
   helper::execute_function_if_exists 'set_up'
 }
 
 function runner::run_set_up_before_script() {
-  helper::execute_function_if_exists 'setUpBeforeScript' # Deprecated: please use set_up_before_script instead.
   helper::execute_function_if_exists 'set_up_before_script'
 }
 
 function runner::run_tear_down() {
-  helper::execute_function_if_exists 'tearDown' # Deprecated: please use tear_down instead.
   helper::execute_function_if_exists 'tear_down'
 }
 
 function runner::run_tear_down_after_script() {
-  helper::execute_function_if_exists 'tearDownAfterScript' # Deprecated: please use tear_down_after_script instead.
   helper::execute_function_if_exists 'tear_down_after_script'
 }
 
 function runner::clean_set_up_and_tear_down_after_script() {
-  helper::unset_if_exists 'setUp' # Deprecated: please use set_up instead.
   helper::unset_if_exists 'set_up'
-  helper::unset_if_exists 'tearDown' # Deprecated: please use tear_down instead.
   helper::unset_if_exists 'tear_down'
-  helper::unset_if_exists 'setUpBeforeScript' # Deprecated: please use set_up_before_script instead.
   helper::unset_if_exists 'set_up_before_script'
-  helper::unset_if_exists 'tearDownAfterScript' # Deprecated: please use tear_down_after_script instead.
   helper::unset_if_exists 'tear_down_after_script'
 }
